#
# spec file for package libmikmod
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libmikmod3
Name:           libmikmod
Version:        3.3.11.1
Release:        2.4
Summary:        MikMod Sound Library
License:        LGPL-2.1-or-later
URL:            http://mikmod.raphnet.net/
Source:         http://sourceforge.net/projects/mikmod/files/%{name}/%{version}/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Patch1:         libmikmod-config.patch
BuildRequires:  makeinfo
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(libpulse-simple)

%description
Libmikmod is a portable sound library, capable of playing samples as
well as module files. It was originally written by Jean-Paul Mikkers
(MikMak) for DOS. It supports OSS /dev/dsp, ALSA, and Esound and can
also write wav files. Supported file formats include mod, stm, s3m,
mtm, xm, and it.

%package -n %{lname}
Summary:        MikMod Sound Library

%description -n %{lname}
Libmikmod is a portable sound library, capable of playing samples as
well as module files. It was originally written by Jean-Paul Mikkers
(MikMak) for DOS. It supports OSS /dev/dsp, ALSA, and Esound and can
also write wav files. Supported file formats include mod, stm, s3m,
mtm, xm, and it.

%package devel
Summary:        Development files for MikMod Sound Library
Requires:       %{lname} = %{version}
Requires:       glibc-devel
Requires(pre):  %{install_info_prereq}

%description devel
This package contains files needed for compiling programs using
libmikmod.

Libmikmod is a portable sound library, capable of playing samples as
well as module files. It was originally written by Jean-Paul Mikkers
(MikMak) for DOS. It supports OSS /dev/dsp, ALSA, and Esound and can
also write wav files. Supported file formats include mod, stm, s3m,
mtm, xm, and it.

%prep
%autosetup -p0

%build
%configure --disable-static --disable-oss
make %{?_smp_mflags}

%install
%make_install
cmp   %{buildroot}%{_includedir}/mikmod{,_build}.h &&
ln -f %{buildroot}%{_includedir}/mikmod{,_build}.h
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig
%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/mikmod.info.gz

%postun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/mikmod.info.gz

%files -n %{lname}
%license COPYING.LIB COPYING.LESSER
%{_libdir}/libmikmod.so.3*

%files devel
%doc README AUTHORS NEWS TODO
%{_bindir}/*-config
%{_datadir}/aclocal/libmikmod.m4
%{_includedir}/*
%{_libdir}/pkgconfig/libmikmod.pc
%{_infodir}/mikmod*
%{_libdir}/libmikmod.so
%{_mandir}/man1/*-config.*

%changelog
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Thu Oct 31 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.3.11
  * Fixed lots of possible crashes in the IT, XM, S3M, STM, STX,
    AMF, IMF, GDM and MED module loaders.
  * Fixed a possible endless loop in the IT loader with
    malformed files.
  * Fixed signed integer overflow leading to crashes in the
    sample loader.
  * Fixed a possible crash in MMCMP depacker with malformed
    files.
  * Fixed the broken fixed-line comment reader which might
    possibly lead to crashes, and also badly translated several
    song messages. The new code is adapted from libopenmpt.
  * Support for building the Windows version using Open Watcom
    compiler.
  * A few minor OS/2 fixes.
  * CMake updates.
  * Other minor fixes/tidy-ups.
  version 3.3.10:
  * Fixed windows builds when UNICODE is defined. (Thanks S.
    Michel).
  version 3.3.9:
  * Amiga, AHI driver: Fixed a crash upon driver shutdown.
  * Amiga: Updates. Added standalone makefiles with cross-build
    support.
  * RAW file writer: Changed to use ansi stdio functions instead
    of posix unistd, for better portability.
  * Playercode: Allocate the right channel reverb buffers only
    if the mixer is setup for stereo mode. (Helps with ports to
    memory-tight platforms. Patch from Andrew Rossignol.)
  * Fixed access to uninitialized memory in the simpleplayMEM
    example program.
  * Added a configuration option to exclude the hqmixer (off by
    default.)
  * Using locale-insensitive ctype.h and casecmp functions in
    library.
  * Configury: New --disable-alldrv option to disable all of the
    audio output drivers.  If additional --enable-xxx options are
    given, the specified drivers will be enabled.
  version 3.3.8:
  * Handle the FastTracker2 pattern loop (E60) bug. Modules
    abusing this bug (roadblas.xm) should play correctly now.
    Thanks to Eugene Toder.
  * AMF loader: Fixed segmentation fault in case of bad sample
    offsets in broken files. (sf.net bug #26, thanks to 'Saga'
    of OpenMPT project for the report and analysis.)
  * AMF loader: Fixed loading of v10 files where sample loop
    start and end values must be read as 32 bits, not 16 bits.
    (Tested with Maelcum's "the tribal zone" and "the way its
    gonna b". Noticed in OpenMPT source)
  * Fixed a possible undefined behavior in the XM loader.
  * Support for MMCMP, Amiga PP20 (PowerPack), STC (Stone
    Cracker S404) and XPK compressed module formats, based on
    public domain code from libmodplug and libxmp.
  * Support for OpenBSD sndio.
  * Fixed SDL output driver, so that it doesn't crash upon
    resetting.
  * Disabled the gt2 loader until it is completed properly. (It
    has been always non-functional since its introduction in
    v3.2.0.)
  * Updated configury. The aix, hpux, bsd/sunaudio and sgi audio
    drivers are now configurable and not built unconditionally.
    Haiku support thanks to Jérôme Duval.
  * Documentation update.
  * Update DOS build for the new djgpp-2.05 release.
  * Minor fix/tidy-ups.
- Spec cleanup
* Tue Feb 10 2015 p.drouand@gmail.com
- Update to version 3.3.7
  * Android support, with the OpenSL ES driver adapted from the old
    libmikmod-android project.
  * Support for AmigaOS and its variants like MorphOS, AROS, and a new
    AHI driver
  * Build system configuration and packaging simplifications, tidy-ups.
  * Several portability tweaks.
  * New PSP driver. (untested. based on older ports from pspdev.)
  * Fix some OS/2 bit rot. (for nostalgia...)
* Wed May  7 2014 reddwarf@opensuse.org
- Modify libmikmod-config.patch to also remove pthreads stuff from
  cflags and ldadd. Now it's "equivalent" to the .pc file.
* Tue May  6 2014 schwab@suse.de
- Add libmikmod-config.patch:
  Remove @LIBRARY_LIB@ from libmikmod-config, which is only needed for
  static linking, which is not possible anyway
* Mon Apr  7 2014 idonmez@suse.com
- Fix Source URL
* Sun Apr  6 2014 stephan.barth@suse.com
- update to version 3.3.6 from 3.3.5
  Changes description from upstream:
  This release adds updates to the umx loader, a fix for a dynamic loading
  issue for ALSA and ESD drivers, a small update to the OSS driver to cover
  less common setups, a minor fix to PulseAudio driver, and build system
  updates (configure and cmake).
* Fri Mar  7 2014 reddwarf@opensuse.org
- Update to version 3.3.5
  + Lots of changes. See NEWS file or http://mikmod.sourceforge.net/#news
- Remove CVE-2007-6720.diff, libmikmod-3.2.0-loopingvolume-fix.diff,
  libmikmod-altivec.patch and libmikmod-lp64.patch. Applied upstream.
- Remove libmikmod-rpmlintrc. Doesn't apply anymore.
- Remove esound-devel BuildRequires
- Add pkg-config, pkgconfig(alsa) and pkgconfig(libpulse-simple) BuildRequires
- Disable OSS sound output
* Thu Apr  4 2013 dvaleev@suse.com
- fix altivec CFLAGS (libmikmod-altivec.patch)
* Tue Mar 26 2013 meissner@suse.com
- merged / ported missing patches:
  - libmikmod-lp64.patch: generic 64bit patch for 64LP architectures
  - CVE-2007-6720.diff:   perhaps missing upstream boundary checks (?)
  - libmikmod-3.2.0-loopingvolume-fix.diff:  seems missing upstream still
* Tue Nov 20 2012 zaitor@opensuse.org
- Update to version 3.2.0:
  + MacOS X CoreAudio driver
  + Carbon support
  + Loader for ASYLUM Music Format v1.0 (.amf) modules, as used in
    crusader games.
  + New function 'Player_QueryVoices' added, which is used to
    return dynamic channel information about the module player.
  + Mixing with floating point output.
  + AIFF disk writer driver.
  + RPM support. To build a rpm, download the tar.gz, and run this:
    %% rpmbuild -tb libmikmod-3.2.0-beta2.tar.gz
  + New NAS driver (Network Audio System). Tested with nasd and
    NCD X terminals.
  + MREADERs now have an iobase member (previously was a static
    variable in mmio.c).
  + Created an example/ subdirectory, to hold programming examples.
  + Added functions to read from memory.
  + Renamed internal _mm_malloc function to MikMod_malloc, which
    is now part of the API.
  + Raw samples can now be loaded using the new Sample_LoadRaw*
    family of functions for sound effects.
  + PowerPC 64 support
  + ALSA driver is now working with "recent" ALSAs.
  + Change MDRIVER "char *" fields to "const char *".
  + Implement a fix to the ALSA driver in MIKMOD_DYNAMIC mode so
    it will allow linking against libmikmod when "-Wl,--no-undefined"
    is passed.
- Bugfixes:
  + The sun driver now compiles on solaris.
  + The wav output driver had problems on big endian systems.
  + A warning in libmikmod.m4 with autoconf 1.8 was fixed.
  + The 'card' argument, supported by the OSS driver was not
    documented via the MDRIVER->CmdLineHelp string.
  + libmikmod-3.1.11-CVE-2010-2546,2971.diff
  + libmikmod-3.1.11-CVE-2009-3995,3996.diff
  + Now checking for linking against -lm.
  + Modified patch of libmikmod-CVE-2009-0179.patch.
  + Apply the libmikmod-CVE-2007-6720.patch.
  + Implement a fix for sprintf-of-list
  + Apply a patch for non-blocking opening of the OSS driver.
  + Fixed the prototypes of vc_callback.
  + Cast a vc_callback parameter to "unsigned char *" instead of "char *",
    becuase the former is what it accepts.
  + Check for Samples' validatity in virtch_common.c.
  + Fix compilation on MSVC.
- Drop all patches, fixed upstream.
- Stop passing autoreconf, not needed anymore since we do not carry
  any patches.
- Bump so name, following upstream changes.
* Fri Sep  7 2012 coolo@suse.com
- add explicit buildrequire makeinfo
* Mon Jun 11 2012 jengelh@inai.de
- Adhere to shlib package naming guidelines
- Parallel build with %%_smp_mflags
- Remove redundant tags/sections from specfile
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Aug 25 2010 prusnak@opensuse.org
- correct fix for CVE-2009-3995 [bnc#625547]
* Thu Apr 22 2010 prusnak@suse.cz
- fix CVE-2009-3995,3996
* Wed Apr 21 2010 prusnak@suse.cz
- fixed CVE-2009-3995 and CVE-2009-3996 [bnc#577875]
* Mon Dec 21 2009 prusnak@suse.cz
- updated to 3.1.12
  * bugfix release
- refreshed all patches
* Sat Dec 19 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Thu Feb 26 2009 prusnak@suse.cz
- fixed CVE-2009-0179 [bnc#468760]
* Fri Jan 23 2009 prusnak@suse.cz
- fixed DoS CVE-2007-6720 [bnc#468760]
* Fri Jan  9 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Aug 31 2007 bk@suse.de
- Remove obsoleted 64-bit patch (fixes background music of pingus)
* Wed Apr 11 2007 sbrabec@suse.cz
- Updated to version 3.1.11-a:
  * work correctly on amd64
  * fixes a warning issued by automake-1.8 in libmikmod.m4
  * includes an updated version of config.guess and config.sub
- Split devel subpackage (#263232).
* Fri Mar 23 2007 schwab@suse.de
- Require audiofile-devel.
- Fix 64bit patch.
* Thu Jan 26 2006 sbrabec@suse.cz
- Added %%install_info_prereq.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Nov  4 2005 ltinkl@suse.cz
- update to 3.1.11
* Thu Sep  8 2005 pth@suse.de
- Fix libmikmod-config for real (#96912)
* Tue Sep  6 2005 jpr@suse.de
- Make sure libmikmod-config reports libdir correctly on all
  architectures (96912)
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Thu Mar  4 2004 tiwai@suse.de
- fixed m4 file for the recent autoconf.
* Sat Feb  7 2004 adrian@suse.de
- fix some autoconf issues
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Feb 14 2003 adrian@suse.de
- fix info file name
* Wed Feb 12 2003 adrian@suse.de
- add %%install_info section
* Tue Aug 20 2002 tiwai@suse.de
- fixed the detection of 64bit architectures [bug #18106]
* Tue Aug  6 2002 adrian@suse.de
- add %%run_ldconfig
* Tue Jun  4 2002 ro@suse.de
- fix file list
* Fri May 31 2002 adrian@suse.de
- update to version 3.1.10
- renamed libmikmo -> libmikmod
- fix for lib64 and ppc64
- add esd support
- add alsa support
- use buildroot
* Sat Nov  4 2000 kukuk@suse.de
- use new long package names
* Wed Jun 21 2000 schwab@suse.de
- Add %%suse_update_config.
* Sun Jun 18 2000 adrian@suse.de
- fixed man path
* Fri Jun 16 2000 adrian@suse.de
- update to 3.1.9
* Fri Jun  2 2000 uli@suse.de
- moved docs to %%{_docdir}
* Thu Mar  2 2000 uli@suse.de
- moved info files to %%{_infodir}
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Sep  7 1999 kettner@suse.de
- New version 3.1.7
* Fri May  7 1999 kettner@suse.de
- Install additional include files for kmikmod
* Thu May  6 1999 kettner@suse.de
- Spec file created from libmikmod-3.1.6.tar.gz by autospec
